@@ -1,3 +1,5 @@
+//! Main block aligner algorithm and supporting data structures.
+
 #[cfg(all(any(target_arch = "x86", target_arch = "x86_64"), target_feature = "avx2"))]
 use crate::avx2::*;
 
@@ -58,6 +60,7 @@ const STEP: usize = if L / 2 < 8 { L / 2 } else { 8 };
 const LARGE_STEP: usize = STEP; // use larger step size when the block size gets large
 const GROW_STEP: usize = L; // used when not growing by powers of 2
 const GROW_EXP: bool = true; // grow by powers of 2
+const X_DROP_ITER: usize = 2; // make sure that the X-drop iteration is truly met instead of just one "bad" step
 impl<'a, M: 'static + Matrix, const TRACE: bool, const X_DROP: bool> Block<'a, M, { TRACE }, { X_DROP }> {
     /// Align two strings with block aligner.
     ///
@@ -150,6 +153,9 @@ impl<'a, M: 'static + Matrix, const TRACE: bool, const X_DROP: bool> Block<'a, M
         // how many steps since the latest best score was encountered
         let mut y_drop_iter = 0;
 
+        // how many steps where the X-drop threshold is met
+        let mut x_drop_iter = 0;
+
         // the state at the previous checkpoint (where latest best score was encountered)
         let mut i_ckpt = self.i;
         let mut j_ckpt = self.j;
@@ -438,9 +444,17 @@ impl<'a, M: 'static + Matrix, const TRACE: bool, const X_DROP: bool> Block<'a, M
                 y_drop_iter = 0;
             }
 
-            if X_DROP && unlikely(off_max < best_max - self.x_drop) {
-                // x drop termination
-                break;
+            if X_DROP {
+                if unlikely(off_max < best_max - self.x_drop) {
+                    if x_drop_iter < X_DROP_ITER - 1 {
+                        x_drop_iter += 1;
+                    } else {
+                        // x drop termination
+                        break;
+                    }
+                } else {
+                    x_drop_iter = 0;
+                }
             }
 
             if unlikely(self.i + block_size > self.query.len() && self.j + block_size > self.reference.len()) {
@@ -937,8 +951,8 @@ impl Trace {
                 res.push(Rectangle {
                     row: *self.block_start.as_ptr().add(i * 2) as usize,
                     col: *self.block_start.as_ptr().add(i * 2 + 1) as usize,
-                    width: *self.block_size.as_ptr().add(i * 2) as usize,
-                    height: *self.block_size.as_ptr().add(i * 2 + 1) as usize
+                    height: *self.block_size.as_ptr().add(i * 2) as usize,
+                    width: *self.block_size.as_ptr().add(i * 2 + 1) as usize
                 });
             }
         }
@@ -1030,6 +1044,9 @@ pub struct PaddedBytes {
 
 impl PaddedBytes {
     /// Create from a byte slice.
+    ///
+    /// Make sure that `block_size` is greater than or equal to the upper bound
+    /// block size used in the `Block::align` function.
     #[inline]
     pub fn from_bytes<M: Matrix>(b: &[u8], block_size: usize) -> Self {
         let mut v = b.to_owned();
@@ -1041,12 +1058,18 @@ impl PaddedBytes {
     }
 
     /// Create from the bytes in a string slice.
+    ///
+    /// Make sure that `block_size` is greater than or equal to the upper bound
+    /// block size used in the `Block::align` function.
     #[inline]
     pub fn from_str<M: Matrix>(s: &str, block_size: usize) -> Self {
         Self::from_bytes::<M>(s.as_bytes(), block_size)
     }
 
     /// Create from the bytes in a string.
+    ///
+    /// Make sure that `block_size` is greater than or equal to the upper bound
+    /// block size used in the `Block::align` function.
     #[inline]
     pub fn from_string<M: Matrix>(s: String, block_size: usize) -> Self {
         let mut v = s.into_bytes();
@@ -1057,22 +1080,22 @@ impl PaddedBytes {
         Self { s: v, len }
     }
 
-    /// Get the byte at a certain index.
+    /// Get the byte at a certain index (unchecked).
     #[inline]
-    pub fn get(&self, i: usize) -> u8 {
-        unsafe { *self.s.as_ptr().add(i) }
+    pub unsafe fn get(&self, i: usize) -> u8 {
+        *self.s.as_ptr().add(i)
     }
 
-    /// Set the byte at a certain index.
+    /// Set the byte at a certain index (unchecked).
     #[inline]
-    pub fn set(&mut self, i: usize, c: u8) {
-        unsafe { *self.s.as_mut_ptr().add(i) = c; }
+    pub unsafe fn set(&mut self, i: usize, c: u8) {
+        *self.s.as_mut_ptr().add(i) = c;
     }
 
     /// Create a pointer to a specific index.
     #[inline]
-    pub fn as_ptr(&self, i: usize) -> *const u8 {
-        unsafe { self.s.as_ptr().add(i) }
+    pub unsafe fn as_ptr(&self, i: usize) -> *const u8 {
+        self.s.as_ptr().add(i)
     }
 
     /// Length of the original string (no padding).
